@@ -29,15 +29,17 @@ gr2gps_latlon = function(gridref, precision = NULL, centre = TRUE){
     # Determine indices of gridrefs that are not UTM30 (which will need transformed)
     i_trans = which(!org_en$PROJECTION %in% c("UTM30","WGS84"))
     
-    # Determine Cartesian (Original projection)
-    org_cart = LatLong_Cartesian(out_latlon$LATITUDE[i_trans], out_latlon$LONGITUDE[i_trans], org_en$PROJECTION[i_trans])
-    
-    # Apply Helmert transformation to convert original projections to WGS84 (Cartesian in WGS84)
-    helm_tran = helmert_trans(x =org_cart$x, y = org_cart$y, z = org_cart$z, trans = paste(org_en$PROJECTION[i_trans],"toWGS84", sep=""))
-    
-    # Convert Cartesian coordinates to Latitude/Longitude (Lat Lon in WGS84)
-    out_latlon[i_trans,] = Cartesian_LatLong(helm_tran$x, helm_tran$y, helm_tran$z, "UTM30")
-    
+	# Determine whether any supplied grid references need reprojection (i.e. are any grid references from UK, Ireland)
+	if(length(i_trans) > 0){
+		# Determine Cartesian (Original projection)
+		org_cart = LatLong_Cartesian(out_latlon$LATITUDE[i_trans], out_latlon$LONGITUDE[i_trans], org_en$PROJECTION[i_trans])
+		
+		# Apply Helmert transformation to convert original projections to WGS84 (Cartesian in WGS84)
+		helm_tran = helmert_trans(x =org_cart$x, y = org_cart$y, z = org_cart$z, trans = paste(org_en$PROJECTION[i_trans],"toWGS84", sep=""))
+		
+		# Convert Cartesian coordinates to Latitude/Longitude (Lat Lon in WGS84)
+		out_latlon[i_trans,] = Cartesian_LatLong(helm_tran$x, helm_tran$y, helm_tran$z, "UTM30")
+    }
     # Return output
     return(out_latlon)
 }
