@@ -1,5 +1,9 @@
 context("Test dataProviders")
 
+# login
+load('~/rnbn_test.rdata')
+nbnLogin(username = UN_PWD$username, password = UN_PWD$password)
+
 test_that("Errors given", {
     expect_error(dataProviders(), 'datasets parameter cannot be NULL') 
 })
@@ -9,7 +13,7 @@ test_that("Warnings given", {
 })
 
 test_that("Providers are returned", {
-    expect_is(dps <- dataProviders(datasets=c('GA001044','GA000426')), 'data.frame')
+    expect_is(dps <- dataProviders(datasets=c('GA000312','GA000426')), 'data.frame')
     expect_that(nrow(dps) == 2, is_true())
-    expect_that('Martin Goodall' %in% dps$contactName, is_true())
+    expect_that('Dr David Roy' %in% dps$contactName, is_true())
 })
